@@ -1,7 +1,8 @@
-﻿
 
 
-__version__ = "0.2021.12.14"
+
+__author__ = "Jürgen Knauth"
+__version__ = "0.2022.4.10"
 
 
 
@@ -49,3 +50,5 @@ from .annotation_logDescend import logDescend
 
 from ._inst import instantiateLogMsgFormatter, instantiate
 from ._wrapMain import wrapMain
+
+
