@@ -1,16 +1,15 @@
 ﻿
 
 
-__version__ = "0.2021.12.14"
-
-
-
 from .AbstractTimeStampFormatter import AbstractTimeStampFormatter
 from .AbstractLogMessageFormatter import AbstractLogMessageFormatter
 
 from .DefaultTimeStampFormatter import DefaultTimeStampFormatter
+from .NoopTimeStampFormatter import NoopTimeStampFormatter
 
 from .ColoredLogMessageFormatter import ColoredLogMessageFormatter, COLOR_LOG_MESSAGE_FORMATTER
 from .HTMLLogMessageFormatter import HTMLLogMessageFormatter, HTML_LOG_MESSAGE_FORMATTER
 from .JSONLogMessageFormatter import JSONLogMessageFormatter, JSON_LOG_MESSAGE_FORMATTER
 from .LogMessageFormatter import LogMessageFormatter, DEFAULT_LOG_MESSAGE_FORMATTER
+
+
